@@ -11,8 +11,10 @@ def change_name(new_name):
     print(f"Nickname changed")
 
 
-def send(message, name=NAME):
+def send(message, name=None):
     '''send the message to the chat'''
+    if name is None:
+        name = NAME
     requests.post(f"{ADDRESS}", data=f"msg~~~{message}|name~~~{name}".encode('utf-8'))
 
 
